pub struct Person {
pub floor_on: usize,
pub floor_to: usize,
pub is_leaving: bool,
pub wait_time: usize,
pub p_out: f64,
pub p_tip: f64,
/* private fields */
}Expand description
Person struct
A Person is aggregated by floors and elevators, and transported between floors
by elevators. The person struct generally should not be directly instantiated;
instead it should be managed in aggregate via the Building type.
Fields
floor_on: usizefloor_to: usizeis_leaving: boolwait_time: usizep_out: f64p_tip: f64Implementations
Sourceimpl Person
Person type implementation
The following functions are used by Elevator/Elevators, Floor/Floors, and
Building types to randomly generate the behavior of Persons
impl Person
Person type implementation
The following functions are used by Elevator/Elevators, Floor/Floors, and
Building types to randomly generate the behavior of Persons
Sourcepub fn from(
p_out: f64,
p_tip: f64,
num_floors: usize,
rng: &mut impl Rng,
) -> Person
pub fn from( p_out: f64, p_tip: f64, num_floors: usize, rng: &mut impl Rng, ) -> Person
Initialize a new person given that persons probability of leaving, the number of floors in the building, and an Rng implementation to randomize the person’s destination floor
Example
let p_out: f64 = 0.05_f64; //Must be between 0 and 1
let p_tip: f64 = 0.2_f64; //Must be between 0 and 1
let num_floors: usize = 5_usize;
let my_rng = rand::thread_rng(); //From rand library
let my_pers: Person = Person::from(p_out, num_floors, &mut my_rng);Sourcepub fn gen_is_leaving(&mut self, rng: &mut impl Rng) -> bool
pub fn gen_is_leaving(&mut self, rng: &mut impl Rng) -> bool
Sample a person’s dst_out distribution to update the person’s is_leaving
property randomly and return the result as a bool. Or if the person is already
leaving then return the property as is.
Sourcepub fn gen_tip(&self, rng: &mut impl Rng) -> bool
pub fn gen_tip(&self, rng: &mut impl Rng) -> bool
Sample a person’s dst_tip distribution to determine whether or not they will
decide to tip.
Sourcepub fn increment_wait_time(&mut self)
pub fn increment_wait_time(&mut self)
Increment a person’s wait_time property by 1_usize. Generally this should be
called by Elevator/Elevators, Floor/Floors, and Building types aggregating
Persons when the Person is not at their desired floor.
Sourcepub fn reset_wait_time(&mut self)
pub fn reset_wait_time(&mut self)
Reset a person’s wait_time property to 0_usize. Generally this should be
called by Elevator/Elevators, Floor/Floors, and Building types aggregating
Persons when the Person finally reaches their desired floor.